# OpenInference Mistral AI Instrumentation
[![PyPI Version](https://img.shields.io/pypi/v/openinference-instrumentation-mistralai.svg)](https://pypi.python.org/pypi/openinference-instrumentation-mistralai) 

Utility functions for OpenInference instrumentation.

## Installation

```shell
pip install openinference-instrumentation
```
